@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Completion::GetoptLongSubcommand;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-08-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -42,7 +42,7 @@ sub weave_section {
         return;
     }
 
-    my $text = $self->section_text({command_name=>$command_name});
+    my $text = $self->section_text_self_completion({command_name=>$command_name});
 
     $self->add_text_to_section($document, $text, 'COMPLETION');
 }
@@ -63,7 +63,7 @@ Pod::Weaver::Section::Completion::GetoptLongSubcommand - Add a COMPLETION sectio
 
 =head1 VERSION
 
-This document describes version 0.02 of Pod::Weaver::Section::Completion::GetoptLongSubcommand (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongSubcommand), released on 2015-04-01.
+This document describes version 0.03 of Pod::Weaver::Section::Completion::GetoptLongSubcommand (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongSubcommand), released on 2015-08-26.
 
 =head1 SYNOPSIS
 
@@ -98,6 +98,7 @@ Please report any bugs or feature requests on the bugtracker website L<https://r
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
